@@ -3,7 +3,7 @@ package org.openstreetmap.osmosis.tagtransform.impl;
 
 import java.util.Collection;
 import java.util.Map;
-
+import org.openstreetmap.osmosis.tagtransform.DataSource;
 import org.openstreetmap.osmosis.tagtransform.Match;
 import org.openstreetmap.osmosis.tagtransform.Output;
 
@@ -11,7 +11,7 @@ import org.openstreetmap.osmosis.tagtransform.Output;
 public class CopyAll implements Output {
 
 	@Override
-	public void apply(Map<String, String> originalTags, Map<String, String> tags, Collection<Match> matches) {
+	public void apply(Map<String, String> originalTags, Map<String, String> tags, Collection<Match> matches, Map<String, DataSource> dataSources) {
 		// copy all tags
 		tags.putAll(originalTags);
 	}
